# -*- coding: utf-8; -*-

from setuptools import setup

setup(name='emojipy',
      version='0.1',
      description='Python wrapper for emojione',
      author='Kaviraj Kanagaraj',
      author_email='kaviraj@launchyard.com',
      packages=['emojipy',],
      test_suite='emojipy.tests',
)



# -*- coding: utf-8; -*-

from __future__ import unicode_literals
from unittest import TestCase
from emojipy import Emoji


class ConversionTests(TestCase):
    """
    Test possible conversions from different kinds of input with
    unicode or shortname at different places
    """
    def setUp(self):
        self.emoji = Emoji
        self.emoji.sprites = False

    def test_single_unicode_char(self):
        unicode = '🐌'
        shortcode = ':snail:'
        image = '<img class="emojione" alt="🐌" src="https://cdn.jsdelivr.net/emojione/assets/3.1/png/64/1f40c.png"/>'
        self.assertEqual(Emoji.unicode_to_image(unicode), image)
        self.assertEqual(Emoji.shortcode_to_image(shortcode), image)

    def test_emoji_inside_sentence(self):
        unicode = 'The 🐌 is EmojiOne\'s original mascot.'
        shortcode = 'The :snail: is EmojiOne\'s original mascot.'
        image     = 'The <img class="emojione" alt="🐌" src="https://cdn.jsdelivr.net/emojione/assets/3.1/png/64/1f40c.png"/> is EmojiOne\'s original mascot.'
        self.assertEqual(Emoji.unicode_to_image(unicode), image)
        self.assertEqual(Emoji.shortcode_to_image(shortcode), image)

    def test_emoji_inside_sentence_with_comma(self):
        unicode = 'The 🐌, is EmojiOne\'s original mascot.'
        shortcode = 'The :snail:, is EmojiOne\'s original mascot.'
        image = 'The <img class="emojione" alt="🐌" src="https://cdn.jsdelivr.net/emojione/assets/3.1/png/64/1f40c.png"/>, is EmojiOne\'s original mascot.'
        self.assertEqual(Emoji.unicode_to_image(unicode), image)
        self.assertEqual(Emoji.shortcode_to_image(shortcode), image)

    def test_emoji_at_start_of_sentence(self):
        unicode = '🐌 mail.'
        shortcode = ':snail: mail.'
        image = '<img class="emojione" alt="🐌" src="https://cdn.jsdelivr.net/emojione/assets/3.1/png/64/1f40c.png"/> mail.'
        self.assertEqual(Emoji.unicode_to_image(unicode), image)
        self.assertEqual(Emoji.shortcode_to_image(shortcode), image)

    def test_emoji_at_start_of_sentence_with_apostrophe(self):
        unicode = '🐌\'s are cool!'
        shortcode = ':snail:\'s are cool!'
        image = '<img class="emojione" alt="🐌" src="https://cdn.jsdelivr.net/emojione/assets/3.1/png/64/1f40c.png"/>\'s are cool!'
        self.assertEqual(Emoji.unicode_to_image(unicode), image)
        self.assertEqual(Emoji.shortcode_to_image(shortcode), image)

    def test_emoji_at_end_of_sentence(self):
        unicode = 'EmojiOne\'s original mascot is 🐌.'
        shortcode = 'EmojiOne\'s original mascot is :snail:.'
        image = 'EmojiOne\'s original mascot is <img class="emojione" alt="🐌" src="https://cdn.jsdelivr.net/emojione/assets/3.1/png/64/1f40c.png"/>.'
        self.assertEqual(Emoji.unicode_to_image(unicode), image)
        self.assertEqual(Emoji.shortcode_to_image(shortcode), image)

    def test_emoji_at_end_of_sentence_with_alternate_punctuation(self):
        unicode = 'EmojiOne\'s original mascot is 🐌!'
        shortcode = 'EmojiOne\'s original mascot is :snail:!'
        image = 'EmojiOne\'s original mascot is <img class="emojione" alt="🐌" src="https://cdn.jsdelivr.net/emojione/assets/3.1/png/64/1f40c.png"/>!'
        self.assertEqual(Emoji.unicode_to_image(unicode), image)
        self.assertEqual(Emoji.shortcode_to_image(shortcode), image)

    def test_emoji_at_end_of_sentence_with_preceeding_colon(self):
        unicode = 'EmojiOne\'s original mascot: 🐌'
        shortcode = 'EmojiOne\'s original mascot: :snail:'
        image = 'EmojiOne\'s original mascot: <img class="emojione" alt="🐌" src="https://cdn.jsdelivr.net/emojione/assets/3.1/png/64/1f40c.png"/>'
        self.assertEqual(Emoji.unicode_to_image(unicode), image)
        self.assertEqual(Emoji.shortcode_to_image(shortcode), image)

    def test_emoji_inside_img_tag(self):
        unicode = 'The <img class="emojione" alt="🐌" src="https://cdn.jsdelivr.net/emojione/assets/3.1/png/64/1f40c.png"/> is EmojiOne\'s original mascot.';
        self.assertEqual(Emoji.unicode_to_image(unicode), unicode)
        self.assertEqual(Emoji.shortcode_to_image(unicode), unicode)

    def test_ascii_char(self):
        ascii = ">:/"
        image = '<img class="emojione" alt="😕" src="https://cdn.jsdelivr.net/emojione/assets/3.1/png/64/1f615.png"/>'
        self.assertEqual(Emoji.ascii_to_image(ascii), image)



# -*- coding: utf-8; -*-

from __future__ import unicode_literals
from unittest import TestCase
from emojipy import Emoji


class EmojipyTest(TestCase):
    def setUp(self):
        pass

    def test_unicode_to_image(self):
        txt = 'Hello world! 😄 :smile:'
        expected = """Hello world! <img class="emojione" alt="😄" src="https://cdn.jsdelivr.net/emojione/assets/3.1/png/64/1f604.png"/> :smile:"""

        self.assertEqual(Emoji.unicode_to_image(txt), expected)

    def test_shortcode_to_image(self):
        txt = 'Hello world! 😄 :smile:'
        expected = """Hello world! 😄 <img class="emojione" alt="😄" src="https://cdn.jsdelivr.net/emojione/assets/3.1/png/64/1f604.png"/>"""
        self.assertEqual(Emoji.shortcode_to_image(txt), expected)
        Emoji.unicode_alt = False
        expected = """Hello world! 😄 <img class="emojione" alt=":smile:" src="https://cdn.jsdelivr.net/emojione/assets/3.1/png/64/1f604.png"/>"""
        self.assertEqual(Emoji.shortcode_to_image(txt), expected)
        Emoji.unicode_alt = True

    def test_shortcode_to_ascii(self):
        txt = 'Hello world! 😄 :slight_smile:'
        expected = [
            'Hello world! 😄 :]',
            'Hello world! 😄 :-)',
            'Hello world! 😄 =)',
            'Hello world! 😄 :)',
            'Hello world! 😄 =]'
        ]

        output = Emoji.shortcode_to_ascii(txt)
        self.assertIn(output, expected)



# -*- coding: utf-8; -*-

from __future__ import unicode_literals
from emojipy import Emoji
from unittest import TestCase


class SpriteTest(TestCase):
    def setUp(self):
        self.emoji = Emoji
        self.emoji.sprites = True
        self.emoji.unicode_alt = True

    def test_unicode_to_image(self):
        """
        Test 'unicode_to_image' method with 'sprites' enabled
        """

        text = 'Hello world! 😄 :smile:'
        expected = 'Hello world! <span class="emojione emojione-32-people _1f604" title=":smile:">😄</span> :smile:'

        self.assertEqual(self.emoji.unicode_to_image(text), expected)



#!/usr/bin/env python3
# -*- coding: utf-8; -*-

from __future__ import unicode_literals
from unittest import TestCase
import json

from emojipy.ruleset import ascii_replace,\
    unicode_replace, shortcode_replace, category_replace

json_path = '../../emoji.json'


class MappingTests(TestCase):
    def setUp(self):
        self.ascii_list = []
        with open(json_path) as json_file:
            content = json_file.read()
            self.json_dict = json.loads(content)
            self.emoji_count = len(self.json_dict)
        for key, value in self.json_dict.items():
            self.ascii_list.extend(value['ascii'])

    def test_unicode_count(self):
        self.assertEqual(self.emoji_count, len(unicode_replace))
        self.assertEqual(len(ascii_replace), len(self.ascii_list))
        self.assertEqual(len(shortcode_replace), len(unicode_replace))
